summaryrefslogtreecommitdiff
path: root/examples_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'examples_test.go')
-rw-r--r--examples_test.go12
1 files changed, 6 insertions, 6 deletions
diff --git a/examples_test.go b/examples_test.go
index 1320cd6..777ae52 100644
--- a/examples_test.go
+++ b/examples_test.go
@@ -7,15 +7,15 @@ import (
"xengineering.eu/soundbox"
)
// ExampleSoundbox demonstrates how to instantiate a Soundbox struct. The used
// MAC address if from a private range according to
// https://www.rfc-editor.org/rfc/rfc9542.html#name-48-bit-mac-documentation-va.
-func ExampleSoundbox() {
- s, err := soundbox.NewSoundbox("00:00:5E:00:53:01")
+func ExampleClient() {
+ s, err := soundbox.NewClient("00:00:5E:00:53:01")
if err != nil {
log.Fatal(err)
}
- fmt.Printf("Soundbox with MAC address %v", s.HardwareAddr)
- // Output: Soundbox with MAC address 00:00:5e:00:53:01
+ fmt.Printf("Client with MAC address %v", s.HardwareAddr)
+ // Output: Client with MAC address 00:00:5e:00:53:01
}
@@ -7,15 +7,15 @@ import (
"xengineering.eu/soundbox"
)
-// ExampleSoundbox demonstrates how to instantiate a Soundbox struct. The used
-// MAC address if from a private range according to
+// ExampleClient demonstrates how to instantiate a Client struct. The used MAC
+// address if from a private range according to
// https://www.rfc-editor.org/rfc/rfc9542.html#name-48-bit-mac-documentation-va.